@@ -47,10 +47,10 @@ class EVA:
     __slots__ = [
         "__data",
         "__extremes",
-        "__extremes_method",
-        "__extremes_type",
         "__extremes_kwargs",
+        "__extremes_method",
         "__extremes_transformer",
+        "__extremes_type",
         "__model",
     ]
 
@@ -212,14 +212,17 @@ class EVA:
         return self.model.loglikelihood
 
     @property
-    def AIC(self) -> float:
+    def AIC(self) -> float:  # noqa: N802
         return self.model.AIC
 
     def test_ks(self, significance_level: float = 0.05) -> KolmogorovSmirnov:
         return KolmogorovSmirnov(
-            extremes=self.extremes,
+            extremes=self.extremes_transformer.transformed_extremes,
             distribution=self.distribution.distribution,
-            fit_parameters=self.model.fit_parameters,
+            fit_parameters={
+                **self.model.fit_parameters,
+                **self.model.distribution._fixed_parameters,
+            },
             significance_level=significance_level,
         )
 
@@ -230,7 +233,7 @@ class EVA:
         # Separator used to separate two columns of the repr block
         sep = " " * 6
 
-        # Widths of left and ridght columns
+        # Widths of left and right columns
         lwidth = (width - len(sep)) // 2
         rwidth = width - (lwidth + len(sep))
 
@@ -291,8 +294,7 @@ class EVA:
 
         # Create summary header
         start_date = (
-            f"{calendar.month_name[self.data.index[0].month]} "
-            f"{self.data.index[0].year}"
+            f"{calendar.month_name[self.data.index[0].month]} {self.data.index[0].year}"
         )
         end_date = (
             f"{calendar.month_name[self.data.index[-1].month]} "
@@ -433,8 +435,7 @@ class EVA:
         block_size: str = "365.2425D",
         errors: typing.Literal["raise", "ignore", "coerce"] = "raise",
         min_last_block: typing.Optional[float] = None,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     @typing.overload
     def get_extremes(
@@ -443,9 +444,8 @@ class EVA:
         extremes_type: typing.Literal["high", "low"] = "high",
         *,
         threshold: float,
-        r: typing.Union[pd.Timedelta, typing.Any] = "24H",
-    ) -> None:
-        ...
+        r: typing.Union[pd.Timedelta, typing.Any] = "24h",
+    ) -> None: ...
 
     def get_extremes(
         self,
@@ -519,7 +519,7 @@ class EVA:
             )
         else:
             self.__extremes_kwargs["threshold"] = kwargs.get("threshold")
-            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.get("r", "24H"))
+            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.get("r", "24h"))
         logger.info("successfully collected extreme value properties")
 
         logger.debug("creating extremes transformer")
@@ -542,8 +542,7 @@ class EVA:
         block_size: str = "365.2425D",
         errors: typing.Literal["raise", "ignore", "coerce"] = "raise",
         min_last_block: typing.Optional[float] = None,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     @typing.overload
     def set_extremes(
@@ -553,9 +552,8 @@ class EVA:
         extremes_type: typing.Literal["high", "low"] = "high",
         *,
         threshold: float,
-        r: typing.Union[pd.Timedelta, typing.Any] = "24H",
-    ) -> None:
-        ...
+        r: typing.Union[pd.Timedelta, typing.Any] = "24h",
+    ) -> None: ...
 
     def set_extremes(
         self,
@@ -626,9 +624,8 @@ class EVA:
             raise TypeError("`extremes` must have numeric values")
         if extremes.name is None:
             extremes.name = self.data.name
-        else:
-            if extremes.name != self.data.name:
-                raise ValueError("`extremes` name doesn't match that of `data`")
+        elif extremes.name != self.data.name:
+            raise ValueError("`extremes` name doesn't match that of `data`")
         if (
             extremes.index.min() < self.data.index.min()
             or extremes.index.max() > self.data.index.max()
@@ -696,7 +693,7 @@ class EVA:
                 raise ValueError("invalid `threshold` value")
 
             # Get `r`
-            extremes_kwargs["r"] = pd.to_timedelta(kwargs.pop("r", "24H"))
+            extremes_kwargs["r"] = pd.to_timedelta(kwargs.pop("r", "24h"))
             if extremes_kwargs["r"] <= pd.to_timedelta("0D"):
                 raise ValueError(
                     "`r` must be a positive timedelta, not %s" % extremes_kwargs["r"]
@@ -731,8 +728,7 @@ class EVA:
         block_size: str = "365.2425D",
         errors: typing.Literal["raise", "ignore", "coerce"] = "raise",
         min_last_block: typing.Optional[float] = None,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     @typing.overload
     @classmethod
@@ -743,9 +739,8 @@ class EVA:
         extremes_type: typing.Literal["high", "low"] = "high",
         *,
         threshold: float,
-        r: typing.Union[pd.Timedelta, typing.Any] = "24H",
-    ) -> None:
-        ...
+        r: typing.Union[pd.Timedelta, typing.Any] = "24h",
+    ) -> None: ...
 
     @classmethod
     def from_extremes(
@@ -864,27 +859,52 @@ class EVA:
     def fit_model(
         self,
         model: typing.Literal["MLE"] = "MLE",
-        distribution: typing.Union[str, scipy.stats.rv_continuous] = None,
+        distribution: typing.Optional[
+            typing.Union[str, scipy.stats.rv_continuous]
+        ] = None,
         distribution_kwargs: typing.Optional[dict] = None,
-    ) -> None:
-        ...
+    ) -> None: ...
+
+    @typing.overload
+    def fit_model(
+        self,
+        model: typing.Literal["Lmoments"] = "Lmoments",
+        distribution: typing.Optional[
+            typing.Union[str, scipy.stats.rv_continuous]
+        ] = None,
+        distribution_kwargs: typing.Optional[dict] = None,
+    ) -> None: ...
+
+    @typing.overload
+    def fit_model(
+        self,
+        model: typing.Literal["MOM"] = "MOM",
+        distribution: typing.Optional[
+            typing.Union[str, scipy.stats.rv_continuous]
+        ] = None,
+        distribution_kwargs: typing.Optional[dict] = None,
+    ) -> None: ...
 
     @typing.overload
     def fit_model(
         self,
         model: typing.Literal["Emcee"] = "Emcee",
-        distribution: typing.Union[str, scipy.stats.rv_continuous] = None,
+        distribution: typing.Optional[
+            typing.Union[str, scipy.stats.rv_continuous]
+        ] = None,
         distribution_kwargs: typing.Optional[dict] = None,
+        *,
         n_walkers: int = 100,
         n_samples: int = 500,
         progress: bool = False,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def fit_model(
         self,
-        model: typing.Literal["MLE", "Emcee"] = "MLE",
-        distribution: typing.Union[str, scipy.stats.rv_continuous] = None,
+        model: typing.Literal["MLE", "Emcee", "Lmoments", "MOM"] = "MLE",
+        distribution: typing.Optional[
+            typing.Union[str, scipy.stats.rv_continuous]
+        ] = None,
         distribution_kwargs: typing.Optional[dict] = None,
         **kwargs,
     ) -> None:
@@ -901,6 +921,10 @@ class EVA:
                     Based on 'scipy' package (scipy.stats.rv_continuous.fit).
                 Emcee - Markov Chain Monte Carlo (MCMC) model.
                     Based on 'emcee' package by Daniel Foreman-Mackey.
+                Lmoments - L-moments (Lmoments) model.
+                    Based on 'lmoments3' package, https://github.com/Ouranosinc/lmoments3
+                MOM - Method of Moments (MOM) model.
+                    Based on 'scipy' package (scipy.stats.rv_continuous.fit).
         distribution : str or scipy.stats.rv_continuous, optional
             Distribution name compatible with scipy.stats
             or a subclass of scipy.stats.rv_continuous.
@@ -910,7 +934,7 @@ class EVA:
             and 'genpareto' and 'expon' for 'POT' extremes.
             Best distribution is selected using the AIC metric.
         distribution_kwargs : dict, optional
-            Special keyword arguments, passsed to the `.fit` method of the distribution.
+            Special keyword arguments, passed to the `.fit` method of the distribution.
             These keyword arguments represent parameters to be held fixed.
             Names of parameters to be fixed must have 'f' prefixes. Valid parameters:
                 - shape(s): 'fc', e.g. fc=0
@@ -925,6 +949,10 @@ class EVA:
             Keyword arguments passed to a model .fit method.
             MLE model:
                 MLE model takes no additional arguments.
+            Lmoments model:
+                Lmoments model takes no additional arguments.
+            MOM model:
+                MOM model takes no additional arguments.
             Emcee model:
                 n_walkers : int, optional
                     The number of walkers in the ensemble (default=100).
@@ -995,7 +1023,7 @@ class EVA:
 
         # Checking if distribution is valid per extreme value theory:
         # Fisher-Tippet-Gnedenko theorem for 'BM'
-        # Pickands–Balkema–de Haan theorem for 'POT'
+        # Pickands-Balkema-de Haan theorem for 'POT'
         if distribution_name is None:
             warnings.warn(
                 message=(
@@ -1004,36 +1032,39 @@ class EVA:
                 ),
                 category=RuntimeWarning,
             )
-        else:
-            if self.extremes_method == "BM" and distribution_name not in [
-                "genextreme",
-                "gumbel_r",
-            ]:
-                warnings.warn(
-                    message=(
-                        f"'{distribution_name}' distribution is not "
-                        f"recommended to be used with extremes extracted "
-                        f"using the 'BM' method, 'genextreme' or 'gumebel_r' "
-                        f"should be used per the Fisher-Tippet-Gnedenko theorem"
-                    ),
-                    category=RuntimeWarning,
-                )
-            elif self.extremes_method == "POT" and distribution_name not in [
-                "genpareto",
-                "expon",
-            ]:
-                warnings.warn(
-                    message=(
-                        f"'{distribution_name}' distribution is not "
-                        f"recommended to be used with extremes extracted "
-                        f"using the 'POT' method, 'genpareto' or 'expon' "
-                        f"should be used per the Pickands–Balkema–de Haan theorem"
-                    ),
-                    category=RuntimeWarning,
-                )
+        elif self.extremes_method == "BM" and distribution_name not in [
+            "genextreme",
+            "gumbel_r",
+        ]:
+            warnings.warn(
+                message=(
+                    f"'{distribution_name}' distribution is not "
+                    f"recommended to be used with extremes extracted "
+                    f"using the 'BM' method, 'genextreme' or 'gumbel_r' "
+                    f"should be used per the Fisher-Tippet-Gnedenko theorem"
+                ),
+                category=RuntimeWarning,
+            )
+        elif self.extremes_method == "POT" and distribution_name not in [
+            "genpareto",
+            "expon",
+        ]:
+            warnings.warn(
+                message=(
+                    f"'{distribution_name}' distribution is not "
+                    f"recommended to be used with extremes extracted "
+                    f"using the 'POT' method, 'genpareto' or 'expon' "
+                    f"should be used per the Pickands-Balkema-de Haan theorem"
+                ),
+                category=RuntimeWarning,
+            )
 
         # Freeze (fix) location parameter for genpareto/expon distributions
-        if distribution_kwargs is None and distribution_name in ["genpareto", "expon"]:
+        if (
+            distribution_kwargs is None
+            and distribution_name in ["genpareto", "expon"]
+            and model != "Lmoments"
+        ):
             distribution_kwargs = {
                 "floc": self.extremes_kwargs.get(
                     "threshold", self.extremes_transformer.transformed_extremes.min()
@@ -1315,10 +1346,10 @@ class EVA:
         )
         return_values = []
         for value in rv:
-            value = np.asarray(a=value, dtype=np.float64)
-            if value.ndim == 0:
-                value = value[np.newaxis]
-            return_values.append(value)
+            arr = np.asarray(a=value, dtype=np.float64)
+            if arr.ndim == 0:
+                arr = arr[np.newaxis]
+            return_values.append(arr)
 
         return pd.DataFrame(
             data=np.transpose(return_values),
