@@ -15,8 +15,7 @@ def get_extremes(
     block_size: str = "365.2425D",
     errors: Literal["raise", "ignore", "coerce"] = "raise",
     min_last_block: Optional[float] = None,
-) -> pd.Series:
-    ...
+) -> pd.Series: ...
 
 
 @overload
@@ -26,9 +25,8 @@ def get_extremes(
     extremes_type: Literal["high", "low"] = "high",
     *,
     threshold: float,
-    r: Union[pd.Timedelta, Any] = "24H",
-) -> pd.Series:
-    ...
+    r: Union[pd.Timedelta, Any] = "24h",
+) -> pd.Series: ...
 
 
 def get_extremes(
