@@ -5,17 +5,49 @@ import numpy as np
 import pandas as pd
 import scipy.stats
 
+try:
+    from lmoments3 import distr as lmoments3_distr
+except ModuleNotFoundError:  # pragma: no cover
+    lmoments3_distr = None
+
 logger = logging.getLogger(__name__)
 
+# Maps scipy distribution names to lmoments3 distribution names
+_SCIPY_TO_LMOMENTS3: typing.Dict[str, str] = {
+    # Exponential
+    "expon": "exp",
+    # Gamma
+    "gamma": "gam",
+    # Generalised Extreme Value
+    "genextreme": "gev",
+    # Generalised Logistic
+    "genlogistic": "glo",
+    # Generalised Normal
+    "gennorm": "gno",
+    # Generalised Pareto
+    "genpareto": "gpa",
+    # Gumbel
+    "gumbel_r": "gum",
+    # Kappa
+    "kappa4": "kap",
+    # Normal
+    "norm": "nor",
+    # Pearson III
+    "pearson3": "pe3",
+    # Weibull
+    "weibull_min": "wei",
+}
+_SUPPORTED_FIT_METHODS: typing.Set[str] = {"MLE", "MOM", "Lmoments"}
+
 
 class Distribution:
-
     __slots__ = [
-        "extremes",
+        "_fixed_parameters",
         "distribution",
         "distribution_parameters",
+        "extremes",
+        "fit_method",
         "fixed_parameters",
-        "_fixed_parameters",
         "free_parameters",
         "mle_parameters",
     ]
@@ -24,12 +56,13 @@ class Distribution:
         self,
         extremes: pd.Series,
         distribution: typing.Union[str, scipy.stats.rv_continuous],
+        fit_method: str = "MLE",
         **kwargs,
     ) -> None:
         """
         Distribution class compatible with pyextremes models.
 
-        It is a wrapper around the scipy.stats.rv_continous class and its subclasses.
+        It is a wrapper around the scipy.stats.rv_continuous class and its subclasses.
         https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rv_continuous.html
 
         Parameters
@@ -40,8 +73,16 @@ class Distribution:
             Distribution name compatible with scipy.stats
             or a subclass of scipy.stats.rv_continuous.
             See https://docs.scipy.org/doc/scipy/reference/stats.html
+        fit_method : str, default 'MLE'
+            Distribution fit method.
+            Controls which method is used when fitting this distribution to data.
+            Supported fit methods:
+             - MLE: Maximum Likelihood Estimation, from scipy
+             - Lmoments: L-moments, from lmoments3
+             - MOM: Method of Moments, from scipy
         kwargs
-            Special keyword arguments, passsed to the `.fit` method of the distribution.
+            Special keyword arguments, passed to the `.fit` method of the distribution
+            (specifics depend on the `fit_method` parameter).
             These keyword arguments represent parameters to be held fixed.
             Names of parameters to be fixed must have 'f' prefixes. Valid parameters:
                 - shape(s): 'fc', e.g. fc=0
@@ -50,15 +91,45 @@ class Distribution:
             By default, no parameters are fixed.
             See documentation of a specific scipy.stats distribution
             for names of available parameters.
+            Lmoments does not allow fixed parameters.
 
         """
         self.extremes = extremes
 
+        # Validate and set fit method
+        if fit_method not in _SUPPORTED_FIT_METHODS:
+            raise ValueError(
+                f"Unsupported fit method '{fit_method}'. "
+                f"Must be one of: {_SUPPORTED_FIT_METHODS}."
+            )
+        if fit_method == "Lmoments":
+            if lmoments3_distr is None:  # pragma: no cover
+                raise ModuleNotFoundError(
+                    "The lmoments3 package is required to use method Lmoments."
+                    "You may install it with `pip install pyextremes[lmoments]` or "
+                    "with `pip install pyextremes[full]`."
+                )
+            if kwargs:
+                raise ValueError("Method Lmoments does not allow fixed parameters.")
+        self.fit_method = fit_method
+
         # Get distribution object
+        self.distribution: scipy.stats.rv_continuous
         if isinstance(distribution, scipy.stats.rv_continuous):
             self.distribution = distribution
         elif isinstance(distribution, str):
-            self.distribution = getattr(scipy.stats, distribution)
+            if self.fit_method == "Lmoments":
+                try:
+                    distribution = _SCIPY_TO_LMOMENTS3[distribution]
+                except KeyError as exc:
+                    raise ValueError(
+                        f"Unsupported distribution for {self.fit_method}: "
+                        f"'{distribution}'; "
+                        f"must be one of: {', '.join(_SCIPY_TO_LMOMENTS3.keys())}."
+                    ) from exc
+                self.distribution = getattr(lmoments3_distr, distribution)
+            else:
+                self.distribution = getattr(scipy.stats, distribution)
             if not isinstance(self.distribution, scipy.stats.rv_continuous):
                 raise ValueError(f"'{distribution}' is not a continuous distribution")
         else:
@@ -72,7 +143,7 @@ class Distribution:
         )
 
         # Get a list of distribution parameter names
-        self.distribution_parameters = []
+        self.distribution_parameters: typing.List[str] = []
         if self.distribution.shapes is not None:
             # Shape parameters must go first due to argument order in scipy.stats
             # (self.distribution_parameters is unpacked using *)
@@ -87,7 +158,7 @@ class Distribution:
         )
 
         # Collect fixed parameters
-        self.fixed_parameters = {}
+        self.fixed_parameters: typing.Dict[str, float] = {}
         for key, value in kwargs.items():
             if key in valid_kwargs:
                 self.fixed_parameters[key] = value
@@ -106,22 +177,22 @@ class Distribution:
             )
 
         # Collect free parameters
-        self.free_parameters = []
+        self.free_parameters: typing.List[str] = []
         for parameter in self.distribution_parameters:
             if parameter not in self._fixed_parameters:
                 self.free_parameters.append(parameter)
 
         # Fit distribution
         self.mle_parameters = self.fit(data=self.extremes.values)
-        free_parameters_mle = ", ".join(
+        free_parameters = ", ".join(
             [f"{key}={value}" for key, value in self.mle_parameters.items()]
         )
         logger.debug(
             "calculated free distribution parameters in: %s",
-            free_parameters_mle,
+            free_parameters,
         )
 
-    def fit(self, data: np.ndarray) -> dict:
+    def fit(self, data: np.ndarray) -> typing.Dict[str, float]:
         """
         Fit distribution to data using the scipy.stats.rv_continuous.fit method.
 
@@ -133,19 +204,35 @@ class Distribution:
         Returns
         -------
         parameters : dict
-            Dictionary with MLE of free distribution parameters.
+            Dictionary with free distribution parameters.
 
         """
-        # Calculate full MLE of distribution parameters
-        full_mle = self.distribution.fit(data=data, **self.fixed_parameters)
 
-        # Package distribtuon parameters into ordered free distribution parameters
-        free_parameters = {}
+        # Calculate full distribution parameters
+        if self.fit_method == "MLE":
+            parameters = self.distribution.fit(
+                data=data, **self.fixed_parameters, method="mle"
+            )
+        elif self.fit_method == "MOM":
+            parameters = self.distribution.fit(
+                data=data, **self.fixed_parameters, method="mm"
+            )
+        elif self.fit_method == "Lmoments":
+            parameters = self.distribution.lmom_fit(data=data)
+            parameters = list(parameters.values())
+        else:
+            raise RuntimeError(  # pragma: no cover
+                f"Invalid fit method '{self.fit_method}'. "
+                f"Must be one of: {', '.join(_SUPPORTED_FIT_METHODS)}."
+            )
+
+        # Package distribution parameters into ordered free distribution parameters
+        free_parameters: typing.Dict[str, float] = {}
         for i, parameter in enumerate(self.distribution_parameters):
             if parameter in self.free_parameters:
-                free_parameters[parameter] = full_mle[i]
+                free_parameters[parameter] = parameters[i]
             else:
-                assert np.isclose(full_mle[i], self._fixed_parameters[parameter])
+                assert np.isclose(parameters[i], self._fixed_parameters[parameter])
         return free_parameters
 
     @property
@@ -166,7 +253,7 @@ class Distribution:
                 [f"{key}={value:,.3f}" for key, value in self.fixed_parameters.items()]
             )
 
-        mle_parameters = ", ".join(
+        parameters = ", ".join(
             [f"{key}={value:,.3f}" for key, value in self.mle_parameters.items()]
         )
 
@@ -176,7 +263,7 @@ class Distribution:
             f"name: {self.name}",
             f"free parameters: {free_parameters}",
             f"fixed parameters: {fixed_parameters}",
-            f"MLE parameters: {mle_parameters}",
+            f"fitted parameters: {parameters}",
         ]
 
         longest_row = max(map(len, summary))
@@ -188,7 +275,7 @@ class Distribution:
 
         return "\n".join(summary)
 
-    def log_probability(self, theta: tuple) -> float:
+    def log_probability(self, theta: typing.Tuple[float, ...]) -> float:
         """
         Calculate log-probability for given free distribution parameters.
 
@@ -245,14 +332,17 @@ class Distribution:
 
         """
         logger.debug("getting initial positions for %s walkers", n_walkers)
-        mle_parameters = [self.mle_parameters[key] for key in self.free_parameters]
+        parameters = [self.mle_parameters[key] for key in self.free_parameters]
         return scipy.stats.norm.rvs(
-            loc=mle_parameters,
+            loc=parameters,
             scale=0.01,
             size=(n_walkers, self.number_of_parameters),
         )
 
-    def free2full_parameters(self, free_parameters) -> np.ndarray:
+    def free2full_parameters(
+        self,
+        free_parameters: typing.Union[typing.Dict[str, float], np.ndarray],
+    ) -> np.ndarray:
         """
         Convert container with free parameters to an array with full parameters.
 
@@ -382,7 +472,7 @@ class Distribution:
                 with length equal to number of `free_parameters` combinations
                     for 1D free_parameters=[1, 2] output is a scalar
                     for 2D free parameters=[[1, 2], [3, 4], [5, 6]]
-                        output is an array of length len(free_paramters)
+                        output is an array of length len(free_parameters)
             If x is a 1D array:
                 output is a 1D or 2D array
                     for 1D free_parameters=[1, 2] output is a 1D array of length len(x)
