@@ -31,7 +31,7 @@ class AbstractModelBaseClass(abc.ABC):
             or a subclass of scipy.stats.rv_continuous.
             See https://docs.scipy.org/doc/scipy/reference/stats.html
         distribution_kwargs : dict, optional
-            Special keyword arguments, passsed to the `.fit` method of the distribution.
+            Special keyword arguments, passed to the `.fit` method of the distribution.
             These keyword arguments represent parameters to be held fixed.
             Names of parameters to be fixed must have 'f' prefixes. Valid parameters:
                 - shape(s): 'fc', e.g. fc=0
@@ -40,10 +40,15 @@ class AbstractModelBaseClass(abc.ABC):
             By default, no parameters are fixed.
             See documentation of a specific scipy.stats distribution
             for names of available parameters.
+            Lmoments does not allow fixed parameters.
         kwargs
             Keyword arguments passed to a model .fit method.
             MLE model:
                 MLE model takes no additional arguments.
+            MOM model:
+                MOM model takes no additional arguments.
+            Lmoments model:
+                Lmoments model takes no additional arguments.
             Emcee model:
                 n_walkers : int, optional
                     The number of walkers in the ensemble (default=100).
@@ -63,7 +68,9 @@ class AbstractModelBaseClass(abc.ABC):
         # Declare extreme value distribution
         distribution_kwargs = distribution_kwargs or {}
         self.distribution = Distribution(
-            extremes=self.extremes, distribution=distribution, **distribution_kwargs
+            extremes=self.extremes,
+            distribution=distribution,
+            **distribution_kwargs,
         )
 
         # Fit the distribution to extremes
@@ -113,7 +120,7 @@ class AbstractModelBaseClass(abc.ABC):
         return np.sum(self.logpdf(x=self.extremes.values))
 
     @property
-    def AIC(self) -> float:
+    def AIC(self) -> float:  # noqa: N802
         """
         Return corrected Akaike Information Criterion (AIC) of the model.
 
