@@ -14,6 +14,13 @@ logger = logging.getLogger(__name__)
 
 
 class Emcee(AbstractModelBaseClass):
+    """
+    Markov Chain Monte Carlo (MCMC) model.
+
+    Built around the 'emcee' package by Daniel Foreman-Mackey
+
+    """
+
     def __init__(
         self,
         extremes: pd.Series,
@@ -23,12 +30,6 @@ class Emcee(AbstractModelBaseClass):
         n_samples: int = 500,
         progress: bool = False,
     ) -> None:
-        """
-        Markov Chain Monte Carlo (MCMC) model.
-
-        Built around the 'emcee' package by Daniel Foreman-Mackey
-
-        """
         super().__init__(
             extremes=extremes,
             distribution=distribution,
@@ -89,10 +90,10 @@ class Emcee(AbstractModelBaseClass):
         def kde_func(x):
             return -kernel(x)[0]
 
-        fit_paramters = self._trace.mean(axis=(0, 1))
+        fit_parameters = self._trace.mean(axis=(0, 1))
         solution = scipy.optimize.minimize(
             kde_func,
-            x0=fit_paramters,
+            x0=fit_parameters,
             method="Nelder-Mead",
         )
         if solution.success:
