@@ -128,7 +128,7 @@ def plot_mean_residual_life(
         if alpha is not None:
             mrl_confidence.append(
                 scipy.stats.norm.interval(
-                    alpha=alpha,
+                    alpha,
                     loc=exceedances.mean(),
                     scale=exceedances.std(ddof=1) / np.sqrt(len(exceedances)),
                 )
@@ -251,7 +251,7 @@ def _calculate_modified_parameters(
 def plot_parameter_stability(
     ts: pd.Series,
     thresholds=None,
-    r: typing.Union[str, pd.Timedelta] = "24H",
+    r: typing.Union[str, pd.Timedelta] = "24h",
     extremes_type: str = "high",
     alpha: typing.Optional[float] = None,
     n_samples: int = 100,
@@ -312,7 +312,7 @@ def plot_parameter_stability(
 
     """
     try:
-        import tqdm  # pylint: disable=import-outside-toplevel
+        import tqdm  # noqa: PLC0415
     except ImportError as error:
         if progress:
             raise ImportError(
@@ -516,7 +516,7 @@ def plot_return_value_stability(
     return_period: float,
     return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
     thresholds=None,
-    r: typing.Union[str, pd.Timedelta] = "24H",
+    r: typing.Union[str, pd.Timedelta] = "24h",
     extremes_type: str = "high",
     distributions: typing.Optional[
         typing.List[typing.Union[str, scipy.stats.rv_continuous]]
@@ -590,7 +590,7 @@ def plot_return_value_stability(
 
     """
     try:
-        import tqdm  # pylint: disable=import-outside-toplevel
+        import tqdm  # noqa: PLC0415
     except ImportError as error:
         if progress:
             raise ImportError(
@@ -724,7 +724,7 @@ def plot_return_value_stability(
 def plot_aic_scores(
     ts: pd.Series,
     thresholds=None,
-    r: typing.Union[str, pd.Timedelta] = "24H",
+    r: typing.Union[str, pd.Timedelta] = "24h",
     extremes_type: str = "high",
     distributions: typing.Optional[
         typing.List[typing.Union[str, scipy.stats.rv_continuous]]
@@ -849,7 +849,7 @@ def plot_threshold_stability(
     return_period: float,
     return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
     thresholds=None,
-    r: typing.Union[str, pd.Timedelta] = "24H",
+    r: typing.Union[str, pd.Timedelta] = "24h",
     extremes_type: str = "high",
     distributions: typing.Optional[
         typing.List[typing.Union[str, scipy.stats.rv_continuous]]
